-------------------------------------------------------------------------------
--
-- Copyright (C) 2014
-- ASTRON (Netherlands Institute for Radio Astronomy) <http://www.astron.nl/>
-- P.O.Box 2, 7990 AA Dwingeloo, The Netherlands
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-------------------------------------------------------------------------------

library IEEE, technology_lib;
use IEEE.std_logic_1164.all;
use work.common_mem_pkg.all;
use technology_lib.technology_select_pkg.all;

entity common_ram_crw_cr is
  generic (
    g_technology : natural := c_tech_select_default;
    g_ram        : t_c_mem := c_mem_ram;
    g_init_file  : string := "UNUSED"
  );
  port (
    -- MM read/write port clock domain
    mm_rst     : in  std_logic := '0';
    mm_clk     : in  std_logic;
    mm_clken   : in  std_logic := '1';
    mm_wr_en   : in  std_logic := '0';
    mm_wr_dat  : in  std_logic_vector(g_ram.dat_w - 1 downto 0) := (others => '0');
    mm_adr     : in  std_logic_vector(g_ram.adr_w - 1 downto 0) := (others => '0');
    mm_rd_en   : in  std_logic := '1';
    mm_rd_dat  : out std_logic_vector(g_ram.dat_w - 1 downto 0);
    mm_rd_val  : out std_logic;

    -- ST read only port clock domain
    st_rst     : in  std_logic := '0';
    st_clk     : in  std_logic;
    st_clken   : in  std_logic := '1';
    st_adr     : in  std_logic_vector(g_ram.adr_w - 1 downto 0) := (others => '0');
    st_rd_en   : in  std_logic := '1';
    st_rd_dat  : out std_logic_vector(g_ram.dat_w - 1 downto 0);
    st_rd_val  : out std_logic
  );
end common_ram_crw_cr;

architecture str of common_ram_crw_cr is
begin
  -- Dual clock domain
  -- Use port a for read/write in MM clock domain
  -- Use port b for read only  in ST clock domain

  u_crw_cr : entity work.common_ram_crw_crw
  generic map (
    g_technology => g_technology,
    g_ram        => g_ram,
    g_init_file  => g_init_file
  )
  port map (
    rst_a     => mm_rst,
    rst_b     => st_rst,
    clk_a     => mm_clk,
    clk_b     => st_clk,
    clken_a   => mm_clken,
    clken_b   => st_clken,
    wr_en_a   => mm_wr_en,
    wr_en_b   => '0',
    wr_dat_a  => mm_wr_dat,
    wr_dat_b  => (others => '0'),
    adr_a     => mm_adr,
    adr_b     => st_adr,
    rd_en_a   => mm_rd_en,
    rd_en_b   => st_rd_en,
    rd_dat_a  => mm_rd_dat,
    rd_dat_b  => st_rd_dat,
    rd_val_a  => mm_rd_val,
    rd_val_b  => st_rd_val
  );
end str;
